# -*- coding: utf-8 -*-


TEST_DATA_INI="""\
[section]
string = foobar
number = 1
boolean = False
float = 2.1
empty = None
"""


TEST_DATA_INI_INTERPOLATION="""\
[section]
string = foobar [%%(test)s]
number = 1
boolean = False
float = 2.1
empty = None
"""


TEST_DATA_JSON = """\
{
  "section": {
    "string": "foobar",
    "number": 1,
    "boolean": false,
    "float": 2.1,
    "empty": null
  }
}
"""

TEST_DATA_JSON5 = """\
{
  section: {
    string: "foobar",
    number: 1,
    boolean: false,
    float: 2.1,
    empty: null,
  },
}
"""

TEST_DATA_TOML = """\
[section]
string = "foobar"
number = 1
boolean = false
float = 2.1
empty = "null"
"""

TEST_DATA_TOML_WITHOUT_EMPTY = """\
[section]
string = "foobar"
number = 1
boolean = false
float = 2.1

"""

TEST_DATA_YAML = """\
section:
  string: foobar
  number: 1
  boolean: false
  float: 2.1
  empty: null
"""

TEST_DATA_YAML_SORTED = """\
section:
  boolean: false
  empty: null
  float: 2.1
  number: 1
  string: foobar"""

TEST_DATA_YAML_FROM_XML = """\
!!omap
- section: !!omap
  - string: foobar
  - number: 1
  - boolean: false
  - float: 2.1
  - empty: null"""

TEST_DATA_XML = """\
<?xml version="1.0" encoding="utf-8"?>
<section>
	<string>foobar</string>
	<number>1</number>
	<boolean>false</boolean>
	<float>2.1</float>
	<empty></empty>
</section>
"""



# -*- coding: utf-8 -*-
import anymarkup
import sys
import click


@click.version_option(version=anymarkup.__version__, prog_name='anymarkup')
@click.group()
def cli():
    """
    anymarkup - Converts markup files from one format to another. Supports ini, json, json5, toml, xml and yaml.
    Source available at: https://github.com/bkabrda/anymarkup

    More help available by running: anymarkup convert --help
    """


@cli.command('convert')
@click.argument('filename', type=click.File('r'), default='-')
@click.option('-f', '--from-format', type=click.Choice(['ini', 'json', 'json5', 'toml', 'yaml', 'xml']), default=None,
              help='Input file format, if not specified, an educated guess will be made')
@click.option('-t', '--to-format', type=click.Choice(['ini', 'json', 'json5', 'toml', 'yaml', 'xml']), default='json',
              help='Output format to serialize to, the default is JSON')
@click.option('--interpolate/--no-interpolate', default=True,
              help='Whether to interpolate strings, the default is True')
def convert(filename, from_format, to_format, interpolate):
    """Parses stdin or a file and converts to the specified format"""

    # Try to parse the file and output in the specified format
    data = anymarkup.parse(filename, format=from_format, interpolate=interpolate)
    serialized = anymarkup.serialize(data, format=to_format)
    click.echo(serialized)

    # Exit if all done
    sys.exit(0)


if __name__ == '__main__':
    cli(prog_name='anymarkup')


# -*- coding: utf-8 -*-
from anymarkup import __version__
from anymarkup.cli import cli
from click.testing import CliRunner
import pytest


@pytest.fixture(scope="class")
def runner():
    return CliRunner()


# Testing the CLI outside the conversion arguments
class TestCli():
    def test_no_arguments(self, runner):
        result = runner.invoke(cli)
        assert result.exit_code == 0
        assert not result.exception

    def test_invalid_command(self, runner):
        result = runner.invoke(cli, ['--foobar'])
        assert result.exit_code != 0
        assert result.exception

    def test_help(self, runner):
        result = runner.invoke(cli, ['--help'])
        assert result.exit_code == 0
        assert not result.exception

    def test_convert_help(self, runner):
        result = runner.invoke(cli, ['convert', '--help'])
        assert result.exit_code == 0
        assert not result.exception

    def test_version(self, runner):
        result = runner.invoke(cli, ['--version'])
        assert result.exit_code == 0
        assert not result.exception
        assert result.output == 'anymarkup, version ' + __version__ + '\n'

    def test_convert_invalid_file(self, runner):
        result = runner.invoke(cli, ['convert', 'foobar'])
        assert result.exit_code != 0
        assert result.exception



# -*- coding: utf-8 -*-
import anymarkup, anymarkup_core


def test_imports():
    for i in ['AnyMarkupError', 'parse', 'parse_file', 'serialize', 'serialize_file']:
        assert getattr(anymarkup, i) is getattr(anymarkup_core, i)



# -*- coding: utf-8 -*-
from anymarkup.cli import cli
from click.testing import CliRunner
import pytest

from .data import TEST_DATA_JSON5


@pytest.fixture(scope="class")
def runner():
    return CliRunner()


# Testing conversion from JSON5
class TestConversionFromJson5():
    def test_convert_no_error(self, runner):
        arguments = [
            ['convert'],
            ['convert', '--from-format', 'json5'],
            ['convert', '--from-format', 'json5', '--to-format', 'ini'],
            ['convert', '--from-format', 'json5', '--to-format', 'json'],
            ['convert', '--from-format', 'json5', '--to-format', 'json5'],
            ['convert', '--from-format', 'json5', '--to-format', 'toml'],
            ['convert', '--from-format', 'json5', '--to-format', 'xml'],
            ['convert', '--from-format', 'json5', '--to-format', 'yaml']
        ]

        for args in arguments:
            result = runner.invoke(cli, args, input=TEST_DATA_JSON5)
            assert result.exit_code == 0
            assert not result.exception

    def test_wrong_input_format_still_works(self, runner):
        arguments = [
            ['convert', '--from-format', 'yaml'],
        ]
        for args in arguments:
            result = runner.invoke(cli, args, input=TEST_DATA_JSON5)
            assert result.exit_code == 0
            assert not result.exception

    def test_wrong_input_format(self, runner):
        arguments = [
            ['convert', '--from-format', 'ini'],
            ['convert', '--from-format', 'json'],
            ['convert', '--from-format', 'toml'],
            ['convert', '--from-format', 'xml'],
        ]

        for args in arguments:
            result = runner.invoke(cli, args, input=TEST_DATA_JSON5)
            assert result.exit_code != 0
            assert result.exception
